| Title: | An RKWard plugin to transpose a data frame, turning rows into columns and columns into rows. |
|---|---|
| Description: | An RKWard plugin to transpose a data frame, turning rows into columns and columns into rows. |
| Authors: | Alfonso Cano Robles |
| Maintainer: | Alfonso Cano Robles <[email protected]> |
| License: | GPL |
| Version: | 0.01.5 |
| Built: | 2026-06-04 10:03:24 UTC |
| Source: | https://github.com/AlfCano/rk.transpose.df |